# Coding guidelines

## Formatting, Linting, ...
Make sure to install all development requirements by running
```sh
uv sync --dev
```

Install pre-commit into your repository:
```sh
pre-commit install
```

From now on when commiting, `pre-commit` will run our formatting & linting tools.
